@@ -1,8 +1,8 @@
 ﻿var settings = {
     tenantUrl: "https://tenant.sharepoint.com",
     webUrl: "/",  //Note:for root web set url to '/'
-    username: "user@tenant.onmicrosoft.com",
-    password: "password"
+    username: "username@tenant.onmicrosoft.com",
+    password: ""
 };
 
-exports.settings = settings;
\ No newline at end of file
+exports.settings = settings;
